# InlineResponse503

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**status** | **str** |  | [optional] 
**info** | [**dict(str, InlineResponse200Info)**](InlineResponse200Info.md) |  | [optional] 
**error** | [**dict(str, InlineResponse200Info)**](InlineResponse200Info.md) |  | [optional] 
**details** | [**dict(str, InlineResponse200Info)**](InlineResponse200Info.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

